import { ABIParameter, FunctionAbi } from '@aztec/foundation/abi';
import { Fr } from '@aztec/foundation/fields';
/**
 * The type of our decoded ABI.
 */
export type DecodedReturn = bigint | boolean | DecodedReturn[] | {
    [key: string]: DecodedReturn;
};
/**
 * Decodes return values from a function call.
 * @param abi - The ABI entry of the function.
 * @param returnValues - The decoded return values.
 * @returns
 */
export declare function decodeReturnValues(abi: FunctionAbi, returnValues: Fr[]): DecodedReturn;
/**
 * Decodes the signature of a function from the name and parameters.
 */
export declare class FunctionSignatureDecoder {
    private name;
    private parameters;
    constructor(name: string, parameters: ABIParameter[]);
    /**
     * Decodes a single function parameter for the function signature.
     * @param param - The parameter to decode.
     * @returns A string representing the parameter type.
     */
    private decodeParameter;
    /**
     * Decodes all the parameters and build the function signature
     * @returns The function signature.
     */
    decode(): string;
}
/**
 * Decodes a function signature from the name and parameters.
 * @param name - The name of the function-
 * @param parameters - The parameters of the function.
 * @returns - The function signature.
 */
export declare function decodeFunctionSignature(name: string, parameters: ABIParameter[]): string;
//# sourceMappingURL=decoder.d.ts.map